#!/usr/bin/env node
var __require = /* @__PURE__ */ ((x) => typeof require !== "undefined" ? require : typeof Proxy !== "undefined" ? new Proxy(x, {
  get: (a, b) => (typeof require !== "undefined" ? require : a)[b]
}) : x)(function(x) {
  if (typeof require !== "undefined")
    return require.apply(this, arguments);
  throw new Error('Dynamic require of "' + x + '" is not supported');
});
var __async = (__this, __arguments, generator) => {
  return new Promise((resolve, reject) => {
    var fulfilled = (value) => {
      try {
        step(generator.next(value));
      } catch (e) {
        reject(e);
      }
    };
    var rejected = (value) => {
      try {
        step(generator.throw(value));
      } catch (e) {
        reject(e);
      }
    };
    var step = (x) => x.done ? resolve(x.value) : Promise.resolve(x.value).then(fulfilled, rejected);
    step((generator = generator.apply(__this, __arguments)).next());
  });
};

// src/index.ts
import { basename, join } from "path";
import { cwd } from "process";
import { program } from "commander";
import { readFileSync, statSync } from "fs";
import glob from "glob";
import fetch from "cross-fetch";
var VERIFY_API_KEY_QUERY = `
  query ApiKeyToOrgID($api_key: String!) {
    api_key_to_org_id(api_key: $api_key)
  }
`;
var GET_SOURCE_MAP_URLS_QUERY = `
  query GetSourceMapUploadUrls($api_key: String!, $paths: [String!]!) {
    get_source_map_upload_urls(api_key: $api_key, paths: $paths)
  }
`;
var uploadSourcemaps = (_0) => __async(void 0, [_0], function* ({
  apiKey,
  appVersion,
  path,
  basePath
}) {
  if (!apiKey || apiKey === "") {
    if (process.env.HIGHLIGHT_SOURCEMAP_UPLOAD_API_KEY) {
      apiKey = process.env.HIGHLIGHT_SOURCEMAP_UPLOAD_API_KEY;
    } else {
      throw new Error("api key cannot be empty");
    }
  }
  const variables = {
    api_key: apiKey
  };
  const res = yield fetch("https://pri.highlight.run", {
    method: "post",
    headers: {
      "Content-Type": "application/json",
      ApiKey: apiKey
    },
    body: JSON.stringify({
      query: VERIFY_API_KEY_QUERY,
      variables
    })
  }).then((response) => response.json()).then((data) => {
    return data;
  }).catch((e) => {
    console.log(e);
  });
  if (!res || !res.data || !res.data.api_key_to_org_id || res.data.api_key_to_org_id === "0") {
    throw new Error("invalid api key");
  }
  let organizationId = res.data.api_key_to_org_id;
  console.info(`Starting to upload source maps from ${path}`);
  const fileList = yield getAllSourceMapFiles([path]);
  if (fileList.length === 0) {
    console.error(
      `Error: No source maps found in ${path}, is this the correct path?`
    );
    console.info("Failed to upload source maps. Please see reason above.");
    return;
  }
  const s3Keys = fileList.map(
    ({ name }) => getS3Key(organizationId, appVersion, basePath, name)
  );
  const urlRes = yield fetch("https://pri.highlight.run", {
    method: "post",
    headers: {
      "Content-Type": "application/json"
    },
    body: JSON.stringify({
      query: GET_SOURCE_MAP_URLS_QUERY,
      variables: {
        api_key: apiKey,
        paths: s3Keys
      }
    })
  }).then((response) => response.json()).then((data) => {
    return data;
  }).catch((e) => {
    console.log(e);
  });
  if (!urlRes || !urlRes.data || !urlRes.data.get_source_map_upload_urls || urlRes.data.get_source_map_upload_urls.length === 0) {
    console.error("Error: Unable to generate source map upload urls.", urlRes);
    console.info("Failed to upload source maps. Please see reason above.");
    return;
  }
  const uploadUrls = urlRes.data.get_source_map_upload_urls;
  yield Promise.all(
    fileList.map(({ path: path2 }, idx) => uploadFile(path2, uploadUrls[idx]))
  );
});
function getAllSourceMapFiles(paths) {
  return __async(this, null, function* () {
    const map = [];
    yield Promise.all(
      paths.map((path) => {
        const realPath = join(cwd(), path);
        if (statSync(realPath).isFile()) {
          map.push({
            path: realPath,
            name: basename(realPath)
          });
          return Promise.resolve();
        }
        return new Promise((resolve) => {
          glob(
            "**/*.js?(.map)",
            { cwd: realPath, nodir: true, ignore: "**/node_modules/**/*" },
            (err, files) => __async(this, null, function* () {
              for (const file of files) {
                map.push({
                  path: join(realPath, file),
                  name: file
                });
              }
              resolve();
            })
          );
        });
      })
    );
    return map;
  });
}
function getS3Key(organizationId, version, basePath, fileName) {
  if (version === null || version === void 0 || version === "" || !version) {
    version = "unversioned";
  }
  return `${organizationId}/${version}/${basePath}${fileName}`;
}
function uploadFile(filePath, uploadUrl) {
  return __async(this, null, function* () {
    const fileContent = readFileSync(filePath);
    yield fetch(uploadUrl, { method: "put", body: fileContent });
    console.log(`Uploaded ${filePath}`);
  });
}
program.name("@highlight-run/sourcemap-uploader").description("Upload Javascript sourcemaps to Highlight");
program.command("upload").option("-k, --apiKey <string>", "The Highlight api key").option("-av, --appVersion <string>", "The current version of your deploy").option(
  "-p, --path <string>",
  "Sets the directory of where the sourcemaps are"
).option(
  "-bp, --basePath",
  "An optional base path for the uploaded sourcemaps"
).action(uploadSourcemaps);
if (__require.main === module) {
  program.parse();
}
export {
  uploadSourcemaps
};
